@@ -2,11 +2,13 @@
 
 import logging
 from imghdr import what
-from os import walk
+from os import walk, access, R_OK
 from pathlib import Path
-from typing import Callable, List
+from typing import Callable, List, Optional
 
+from duplicate_images.common import path_with_parent
 from duplicate_images.function_types import Results
+from duplicate_images.hash_store import PickleHashStore
 from duplicate_images.image_pair_finder import ImagePairFinder
 from duplicate_images.logging import setup_logging
 from duplicate_images.methods import ACTIONS_ON_EQUALITY, IMAGE_HASH_ALGORITHM
@@ -15,8 +17,8 @@ from duplicate_images.parse_commandline import parse_command_line
 
 
 def is_image_file(filename: Path) -> bool:
-    """Returns True if filename is an image file"""
-    if filename.is_file() and not filename.is_symlink():
+    """Returns True if filename is a readable image file"""
+    if access(filename, R_OK) and not filename.is_symlink():
         return what(filename) is not None
     return False
 
@@ -36,14 +38,18 @@ def files_in_dirs(
 
 
 def get_matches(
-        root_directories: List[Path], algorithm: str,
-        parallel_options: ParallelOptions = ParallelOptions()
+        root_directories: List[Path], algorithm: str, hash_store_path: Optional[Path] = None,
+        show_progress_bars: bool = False, parallel_options: ParallelOptions = ParallelOptions()
 ) -> Results:
     hash_algorithm = IMAGE_HASH_ALGORITHM[algorithm]
     image_files = sorted(files_in_dirs(root_directories, is_image_file))
     logging.info("%d total files", len(image_files))
+    logging.info("Computing image hashes")
 
-    return ImagePairFinder(image_files, hash_algorithm, parallel_options).get_pairs()
+    with PickleHashStore.create(hash_store_path) as hash_store:
+        return ImagePairFinder.create(
+            image_files, hash_algorithm, parallel_options, show_progress_bars, hash_store
+        ).get_pairs()
 
 
 def execute_actions(matches: Results, action_name: str) -> None:
@@ -55,18 +61,15 @@ def execute_actions(matches: Results, action_name: str) -> None:
             continue
 
 
-def path_names_with_parent(folders: List[Path]) -> str:
-    return ' '.join(['/'.join(str(folder).split('/')[-2:]) for folder in folders])
-
-
 def main() -> None:
     args = parse_command_line()
     setup_logging(args)
-    logging.info('Scanning %s', path_names_with_parent(args.root_directory))
+    for folder in args.root_directory:
+        logging.info('Scanning %s', path_with_parent(folder))
     try:
         matches = get_matches(
             [Path(folder) for folder in args.root_directory], args.algorithm,
-            ParallelOptions(args.parallel, args.chunk_size)
+            Path(args.hash_db), args.progress, ParallelOptions(args.parallel)
         )
         logging.info("%d matches", len(matches))
         execute_actions(matches, args.on_equal)
